@@ -509,7 +509,8 @@ class BaseIdentityPlugin(plugin.BaseAuthPlugin):
         return data.api_version
 
     def get_all_version_data(self, session, interface='public',
-                             region_name=None, **kwargs):
+                             region_name=None, service_type=None,
+                             **kwargs):
         """Get version data for all services in the catalog.
 
         :param session: A session object that can be used for communication.
@@ -522,6 +523,9 @@ class BaseIdentityPlugin(plugin.BaseAuthPlugin):
             Region of endpoints to get version data for. A valueof None
             indicates that all regions should be queried. (optional, defaults
             to None)
+        :param string service_type:
+            Limit the version data to a single service. (optional, defaults
+            to None)
         :returns: A dictionary keyed by region_name with values containing
             dictionaries keyed by interface with values being a list of
             :class:`~keystoneauth1.discover.VersionData`.
@@ -530,11 +534,16 @@ class BaseIdentityPlugin(plugin.BaseAuthPlugin):
         catalog = self.get_access(session).service_catalog
         version_data = {}
         endpoints_data = catalog.get_endpoints_data(
-            interface=interface, region_name=region_name)
+            interface=interface,
+            region_name=region_name,
+            service_type=service_type,
+        )
+
+        for endpoint_service_type, services in endpoints_data.items():
+            if service_types.is_known(endpoint_service_type):
+                endpoint_service_type = service_types.get_service_type(
+                    endpoint_service_type)
 
-        for service_type, services in endpoints_data.items():
-            if service_types.is_known(service_type):
-                service_type = service_types.get_service_type(service_type)
             for service in services:
                 versions = service.get_all_version_string_data(
                     session=session,
@@ -548,7 +557,7 @@ class BaseIdentityPlugin(plugin.BaseAuthPlugin):
                 interface = service.interface.rstrip('URL')
                 if interface not in regions:
                     regions[interface] = {}
-                regions[interface][service_type] = versions
+                regions[interface][endpoint_service_type] = versions
 
         return version_data
 
